summaryrefslogtreecommitdiff
path: root/test
diff options
context:
space:
mode:
Diffstat (limited to 'test')
-rw-r--r--test/motion_sense.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/test/motion_sense.c b/test/motion_sense.c
index ab07a41e96..1ec3d4ad60 100644
--- a/test/motion_sense.c
+++ b/test/motion_sense.c
@@ -86,13 +86,13 @@ static int test_lid_angle(void)
msleep(5);
TEST_ASSERT(motion_get_lid_angle() == 90);
/* Set lid open to -135. */
mock_x_acc[ACCEL_LID] = 500;
mock_y_acc[ACCEL_LID] = 0;
mock_z_acc[ACCEL_LID] = -500;
task_wake(TASK_ID_MOTIONSENSE);
msleep(5);
- TEST_ASSERT(motion_get_lid_angle() == -135);
+ TEST_ASSERT(motion_get_lid_angle() == 225);
/*
* Align base with hinge and make sure it returns unreliable for angle.
@@ -86,13 +86,13 @@ static int test_lid_angle(void)
msleep(5);
TEST_ASSERT(motion_get_lid_angle() == 90);
- /* Set lid open to -135. */
+ /* Set lid open to 225. */
mock_x_acc[ACCEL_LID] = 500;
mock_y_acc[ACCEL_LID] = 0;